# Geophysics Analysis

A package that contains various functions to aid with the analysis of geophysical fields, especially those in netcdf format. Included are functions that address:

1. Calculations
2. Data Importing
3. netCDF
4. Discrete Grid Considerations
5. Field Manipulations
6. Plotting
7. Synthetic Data
8. Trends
9. Statistics

